@@ -4,7 +4,7 @@ from aiida.orm import load_node
 from aiida.engine.launch import submit
 from hzdplugins.aiidaplugins.constants import results_keys_set, slurm_options
 
-def qePwOriginalSubmit(results, codename, structure, add_parameters={}, del_parameters={}, kpoints, pseudo_family, cluster_options={}, metadata):
+def qePwOriginalSubmit(results, codename, structure, kpoints, pseudo_family, metadata, add_parameters={}, del_parameters={}, cluster_options={}):
 
     """
 
